==> bigloo2.0a.tar.gz: bigloo2.0a/comptime/Init/extend.scm <==
;*---------------------------------------------------------------------*/
;*   A pratical implementation for the Scheme programming language     */
;*                                                                     */
;*                                    ,--^,                            */
;*                              _ ___/ /|/                             */
;*                          ,;'( )__, ) '                              */
;*                         ;;  //   L__.                               */
;*                         '   \\   /  '                               */
;*                              ^   ^                                  */
;*                                                                     */
;*   Copyright (c) 1992-1999 Manuel Serrano                            */
;*                                                                     */
;*     Bug descriptions, use reports, comments or suggestions are      */
;*     welcome. Send them to                                           */
;*       bigloo-request@kaolin.unice.fr                                */
;*       http://kaolin.unice.fr/bigloo                                 */
;*                                                                     */
;*   This program is free software; you can redistribute it            */
;*   and/or modify it under the terms of the GNU General Public        */
;*   License as published by the Free Software Foundation; either      */
;*   version 2 of the License, or (at your option) any later version.  */
;*                                                                     */
;*   This program is distributed in the hope that it will be useful,   */
;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
;*   GNU General Public License for more details.                      */
;*                                                                     */
;*   You should have received a copy of the GNU General Public         */
;*   License along with this program; if not, write to the Free        */
;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
;*   MA 02111-1307, USA.                                               */
;*---------------------------------------------------------------------*/
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime/Init/extend.scm             */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Oct 28 08:37:41 1994                          */
;*    Last change :  Tue Oct  6 15:08:40 1998 (serrano)                */
;*    -------------------------------------------------------------    */
;*    La lecture des extensions (isole'es pour ne pas avoir le pbm     */
;*    des PRIMOPs trop nombreuses).                                    */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module init_extend
    (export (load-extend ::bstring))
    (import engine_param
	    tools_file))

;*---------------------------------------------------------------------*/
;*    load-extend ...                                                  */
;*---------------------------------------------------------------------*/
(define (load-extend extend-name)
   (let ((fname (find-file/path extend-name *lib-dir*)))
      (if fname
	  (loadq fname)
	  (error "parse-args" "Can't find extend file" extend-name))))

==> bigloo-4.5b.tar.gz: bigloo-4.5b/comptime/Init/extend.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime/Init/extend.scm             */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Oct 28 08:37:41 1994                          */
;*    Last change :  Wed Dec 27 15:33:57 2006 (serrano)                */
;*    Copyright   :  1992-2006 Manuel Serrano, see LICENSE file        */
;*    -------------------------------------------------------------    */
;*    La lecture des extensions (isole'es pour ne pas avoir le pbm     */
;*    des PRIMOPs trop nombreuses).                                    */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module init_extend
   (include "Engine/pass.sch")
   (export  (load-extend ::bstring))
   (import  engine_param
	    tools_error))

;*---------------------------------------------------------------------*/
;*    load-extend ...                                                  */
;*---------------------------------------------------------------------*/
(define (load-extend extend-name)
   (unless (member extend-name *extend-table*)
      (set! *extend-table* (cons extend-name *extend-table*))
      (let ((fname (find-file/path extend-name *lib-dir*)))
	 (if fname
	     (begin
		(pass-prelude fname)
		(loadq fname))
	     (let ((fname (find-file/path (string-append extend-name ".init")
					  *lib-dir*)))
		(if fname
		    (begin
		       (pass-prelude fname)
		       (loadq fname))
		    (error "parse-args"
			   "Can't find extend file"
			   extend-name)))))))

;*---------------------------------------------------------------------*/
;*    *extend-table* ...                                               */
;*---------------------------------------------------------------------*/
(define *extend-table* '())
